import { AxiosError } from "axios";
import { Exception } from "oly";
/**
 * Exception wrapper of AxiosError. <br/>
 *
 * ### Fields
 *
 * | | type | default  | description |
 * |--|--|--|--|
 * | status | number | -1 | HTTP status |
 * | body | any | undefined | HTTP response body |
 * | cause | AxiosError | N/A | axios error |
 *
 * ```ts
 * try {
 *   await http.get("/");
 * } catch(e) {
 *   if(e instanceof HttpClientException) {
 *
 *     if (e.status === 401) {
 *       // ...
 *     }
 *   }
 * }
 * ```
 *
 * ### Follow HttpServerException
 *
 * ```ts
 * try {
 *   await http.get("/");
 * } catch(e) {
 *   if (e instanceof HttpClientException) {
 *
 *     if (e.isHttpServerException()) {
 *        (e as HttpClientException<HttpServerException>)
 *         .body
 *         .message; // ...
 *     }
 *   }
 * }
 * ```
 */
export declare class HttpClientException<T = any> extends Exception {
    /**
     * Status of the failed request.
     */
    status: number;
    /**
     * Response body if exists.
     */
    body: T;
    /**
     * AxiosError is always the cause.
     * This is very useful when you have no response (like e no network)
     */
    cause: AxiosError;
    constructor(error: AxiosError);
    toJSON(): object;
    isHttpServerException(withName?: string): boolean;
}
