"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var oly_1 = require("oly");
var errors_1 = require("../constants/errors");
/**
 * Public API exception. See ApiProvider.
 *
 * Note:
 * - there is no cause in #toJSON() in production. (security)
 * - stacktrace is always available on logging.
 * - status is added (default to 500)
 *
 * ```ts
 * class A {
 *    index() {
 *      throw new HttpServerException();
 *    }
 * }
 * ```
 *
 * Like others exceptions, this is designed to be extended.
 * ```ts
 * class BadRequestException extends HttpServerException {
 *    status = 400;
 * }
 * ```
 */
var HttpServerException = /** @class */ (function (_super) {
    tslib_1.__extends(HttpServerException, _super);
    function HttpServerException() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.message = errors_1.olyHttpErrors.internalError();
        _this.status = 500;
        return _this;
    }
    HttpServerException.prototype.toJSON = function () {
        return tslib_1.__assign({}, _super.prototype.toJSON.call(this), { status: this.status });
    };
    return HttpServerException;
}(oly_1.Exception));
exports.HttpServerException = HttpServerException;
//# sourceMappingURL=HttpServerException.js.map