/// <reference types="node" />
import { AxiosRequestConfig, AxiosResponse } from "axios";
import * as Koa from "koa";
import { Kernel } from "oly";
import { ZlibOptions } from "zlib";
import { HttpClientException } from "./exceptions/HttpClientException";
/**
 * Override default koa context.
 * But, it's better to use IKoaContext.
 */
declare module "koa" {
    interface Context {
        kernel: Kernel;
    }
}
export interface IKoaRequest extends Koa.Request {
}
export interface IKoaResponse extends Koa.Response {
}
/**
 * Koa context with oly kernel.
 */
export interface IKoaContext extends Koa.Context {
    kernel: Kernel;
    request: IKoaRequest;
    response: IKoaResponse;
}
/**
 * Middleware with our Koa.Context
 */
export declare type IKoaMiddleware = (ctx: IKoaContext, next: () => Promise<void>) => any;
/**
 * https://github.com/koajs/static
 */
export interface IServeOptions {
    index?: boolean | string;
    defer?: boolean;
    maxage?: number;
    hidden?: boolean;
    gzip?: boolean;
}
/**
 * https://github.com/koajs/compress
 */
export interface ICompressOptions extends ZlibOptions {
    filter?: (contentType: string) => boolean;
    threshold?: number;
}
/**
 * https://github.com/koajs/cors
 */
export interface ICorsOptions {
    origin?: string | Function;
    allowMethods?: string | string[];
    exposeHeaders?: string | string[];
    allowHeaders?: string | string[];
    maxAge?: string | number;
    credentials?: boolean;
    keepHeadersOnError?: boolean;
}
/**
 * Wrap AxiosResponse with template.
 * Add template.
 * @alias
 */
export interface IHttpResponse<T> extends AxiosResponse {
    data: T;
}
/**
 * Wrap AxiosRequest.
 * @alias
 */
export declare type IHttpRequest = AxiosRequestConfig;
/**
 *
 */
export interface IHttpClientBeforeEvent {
    request: IHttpRequest;
}
/**
 *
 */
export interface IHttpClientSuccessEvent<T = any> {
    response: IHttpResponse<T>;
}
/**
 *
 */
export interface IHttpClientErrorEvent {
    error: HttpClientException;
}
