import { Kernel } from "oly";
import { ICompressOptions, ICorsOptions, IKoaContext, IKoaMiddleware, IServeOptions } from "./interfaces";
/**
 * https://github.com/koajs/static
 *
 * @param root - absolute/relative path to folder
 * @param options - Koa Static options
 */
export declare const serve: (root: string, options?: IServeOptions | undefined) => IKoaMiddleware;
/**
 * https://github.com/koajs/compress
 *
 * @param options     Koa Compress options
 */
export declare const compress: (options?: ICompressOptions | undefined) => IKoaMiddleware;
/**
 * https://github.com/koajs/cors
 *
 * ```ts
 * import { Kernel } from "oly";
 * import { HttpServerProvider, cors } from "oly-http";
 *
 * Kernel
 *   .create()
 *   .configure(k => k
 *     .get(HttpServerProvider)
 *     .use(cors()))
 *   .start()
 *   .catch(console.error);
 * ```
 *
 * @param options     Koa Cors Options
 */
export declare const cors: (options?: ICorsOptions | undefined) => IKoaMiddleware;
/**
 * https://github.com/koajs/mount
 *
 * ```ts
 * import { Kernel } from "oly";
 * import { HttpServerProvider, mount } from "oly-http";
 *
 * Kernel
 *   .create()
 *   .configure(k => k
 *     .get(HttpServerProvider)
 *     .use(mount("/hi", ctx => ctx.body = "Hi!")))
 *   .start()
 *   .catch(console.error);
 * ```
 *
 * @param path        url path ('/', or '/api', ...)
 * @param middleware  Middleware to mount
 */
export declare const mount: (path: string, middleware: IKoaMiddleware) => IKoaMiddleware;
/**
 * https://github.com/venables/koa-helmet
 *
 * @middleware
 * @param opt     helmet options
 */
export declare const helmet: (opt?: object) => IKoaMiddleware;
/**
 * Attach a fresh kernel fork to the current koa context.
 *
 * @param kernel    Kernel to fork
 */
export declare const context: (kernel: Kernel) => (ctx: IKoaContext, next: Function) => any;
