"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// --
var koaStatic = require("koa-static"); // tslint:disable-line
var koaCompress = require("koa-compress"); // tslint:disable-line
var koaMount = require("koa-mount"); // tslint:disable-line
var koaHelmet = require("koa-helmet"); // tslint:disable-line
var koaCors = require("kcors"); // tslint:disable-line
/**
 * https://github.com/koajs/static
 *
 * @param root - absolute/relative path to folder
 * @param options - Koa Static options
 */
exports.serve = function (root, options) { return koaStatic(root, options); };
/**
 * https://github.com/koajs/compress
 *
 * @param options     Koa Compress options
 */
exports.compress = function (options) { return koaCompress(options); };
/**
 * https://github.com/koajs/cors
 *
 * ```ts
 * import { Kernel } from "oly";
 * import { HttpServerProvider, cors } from "oly-http";
 *
 * Kernel
 *   .create()
 *   .configure(k => k
 *     .get(HttpServerProvider)
 *     .use(cors()))
 *   .start()
 *   .catch(console.error);
 * ```
 *
 * @param options     Koa Cors Options
 */
exports.cors = function (options) { return koaCors(options); };
/**
 * https://github.com/koajs/mount
 *
 * ```ts
 * import { Kernel } from "oly";
 * import { HttpServerProvider, mount } from "oly-http";
 *
 * Kernel
 *   .create()
 *   .configure(k => k
 *     .get(HttpServerProvider)
 *     .use(mount("/hi", ctx => ctx.body = "Hi!")))
 *   .start()
 *   .catch(console.error);
 * ```
 *
 * @param path        url path ('/', or '/api', ...)
 * @param middleware  Middleware to mount
 */
exports.mount = function (path, middleware) { return koaMount(path, middleware); };
/**
 * https://github.com/venables/koa-helmet
 *
 * @middleware
 * @param opt     helmet options
 */
exports.helmet = function (opt) {
    if (opt === void 0) { opt = {}; }
    return koaHelmet(opt || { noCache: false });
};
/**
 * Attach a fresh kernel fork to the current koa context.
 *
 * @param kernel    Kernel to fork
 */
exports.context = function (kernel) { return function (ctx, next) {
    ctx.kernel = kernel.fork();
    ctx.kernel.state("Koa.context", ctx);
    return next();
}; };
//# sourceMappingURL=middlewares.js.map