import { Server } from "http";
import * as Koa from "koa";
import { IProvider, Kernel, Logger } from "oly";
import { IKoaMiddleware } from "../interfaces";
/**
 * Default http server provider
 */
export declare class HttpServerProvider implements IProvider {
    /**
     * Set hostname of the http server.
     */
    protected readonly host: string;
    /**
     * Set port of the http server.
     */
    protected readonly port: number;
    /**
     * Kernel.
     * We use kernel here to fork context on each request.
     */
    protected readonly kernel: Kernel;
    /**
     * Logger.
     */
    protected readonly logger: Logger;
    /**
     * Koa application.
     * Http Server is provided with Koa.
     */
    protected readonly app: Koa;
    /**
     * NodeJS Http Server instance.
     */
    protected http: Server;
    /**
     * Hostname getter.
     * Protocol is forced to http as we only use Http Server.
     */
    readonly hostname: string;
    /**
     * Configure middleware before onStart().
     *
     * @param middleware
     */
    use(middleware: IKoaMiddleware): HttpServerProvider;
    /**
     * Start the http server.
     * Listen new connections.
     */
    onStart(): Promise<void>;
    /**
     * Stop http server.
     * We don't wait the callback.
     */
    onStop(): Promise<void>;
    /**
     * Use helmet middleware.
     *
     * @overridable
     */
    protected useHelmet(): HttpServerProvider;
    /**
     * Use a http logger middleware.
     *
     * @overridable
     */
    protected useLogger(): HttpServerProvider;
    /**
     * @overridable
     */
    protected createServer(): Server;
}
