import { AxiosInstance, AxiosRequestConfig } from "axios";
import { Kernel, Logger } from "oly";
import { IHttpRequest, IHttpResponse } from "../interfaces";
/**
 * Simple wrapper of Axios.
 * Designed to be extended.
 */
export declare class HttpClient {
    protected axios: AxiosInstance;
    protected logger: Logger;
    protected kernel: Kernel;
    /**
     * Configure a new axios instance.
     * Useful for attach BASE_URL or similar stuff.
     * > Use it for test only.
     *
     * @param options   Axios configuration
     * @internal
     */
    with(options: AxiosRequestConfig): this;
    /**
     * Create a new http request.
     *
     * @param request   Http Request Options
     */
    request<T = any>(request: IHttpRequest): Promise<IHttpResponse<T>>;
    /**
     * Make a GET request.
     * ```ts
     * await http.get("/users");
     * ```
     *
     * @param url       Complete url
     * @param options   Request options
     */
    get<T = any>(url: string, options?: IHttpRequest): Promise<T>;
    /**
     * Make a POST request.
     * ```ts
     * await http.post("/users", {name: "Jean"});
     * ```
     *
     * @param url       Complete url
     * @param body      Request body
     * @param options   Request options
     */
    post<T = any>(url: string, body?: any, options?: IHttpRequest): Promise<T>;
    /**
     * Make a PUT request.
     * ```ts
     * await http.put("/users/1", {name: "Jean"});
     * ```
     *
     * @param url       Complete url
     * @param body      Request body
     * @param options   Request options
     */
    put<T = any>(url: string, body?: any, options?: IHttpRequest): Promise<T>;
    /**
     * Make a DEL request.
     * ```ts
     * await http.del("/users/1");
     * ```
     *
     * @param url       Complete url
     * @param options   Request options
     */
    del<T = any>(url: string, options?: IHttpRequest): Promise<T>;
}
