"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var axios_1 = require("axios");
var oly_1 = require("oly");
var events_1 = require("../constants/events");
var HttpClientException_1 = require("../exceptions/HttpClientException");
/**
 * Simple wrapper of Axios.
 * Designed to be extended.
 */
var HttpClient = /** @class */ (function () {
    function HttpClient() {
        this.axios = axios_1.default.create();
    }
    /**
     * Configure a new axios instance.
     * Useful for attach BASE_URL or similar stuff.
     * > Use it for test only.
     *
     * @param options   Axios configuration
     * @internal
     */
    HttpClient.prototype.with = function (options) {
        this.axios = axios_1.default.create(options);
        return this;
    };
    /**
     * Create a new http request.
     *
     * @param request   Http Request Options
     */
    HttpClient.prototype.request = function (request) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var response, e_1, error;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        request.method = request.method || "GET";
                        request.url = request.url || "/";
                        this.logger.debug("fetch " + request.method + " " + request.url, { request: request });
                        return [4 /*yield*/, this.kernel.emit(events_1.olyHttpEvents.HTTP_CLIENT_BEGIN, { request: request })];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2:
                        _a.trys.push([2, 5, , 7]);
                        return [4 /*yield*/, this.axios.request(request)];
                    case 3:
                        response = _a.sent();
                        return [4 /*yield*/, this.kernel.emit(events_1.olyHttpEvents.HTTP_CLIENT_SUCCESS, { response: response })];
                    case 4:
                        _a.sent();
                        return [2 /*return*/, response];
                    case 5:
                        e_1 = _a.sent();
                        error = new HttpClientException_1.HttpClientException(e_1);
                        this.logger.debug("request " + request.method + " " + request.url + " has failed", { error: error });
                        return [4 /*yield*/, this.kernel.emit(events_1.olyHttpEvents.HTTP_CLIENT_ERROR, { error: error })];
                    case 6:
                        _a.sent();
                        throw error;
                    case 7: return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Make a GET request.
     * ```ts
     * await http.get("/users");
     * ```
     *
     * @param url       Complete url
     * @param options   Request options
     */
    HttpClient.prototype.get = function (url, options) {
        if (options === void 0) { options = {}; }
        options.url = url;
        return this.request(options).then(function (_a) {
            var data = _a.data;
            return data;
        });
    };
    /**
     * Make a POST request.
     * ```ts
     * await http.post("/users", {name: "Jean"});
     * ```
     *
     * @param url       Complete url
     * @param body      Request body
     * @param options   Request options
     */
    HttpClient.prototype.post = function (url, body, options) {
        if (body === void 0) { body = {}; }
        if (options === void 0) { options = {}; }
        options.method = "POST";
        options.url = url;
        options.data = body;
        return this.request(options).then(function (_a) {
            var data = _a.data;
            return data;
        });
    };
    /**
     * Make a PUT request.
     * ```ts
     * await http.put("/users/1", {name: "Jean"});
     * ```
     *
     * @param url       Complete url
     * @param body      Request body
     * @param options   Request options
     */
    HttpClient.prototype.put = function (url, body, options) {
        if (body === void 0) { body = {}; }
        if (options === void 0) { options = {}; }
        options.method = "PUT";
        options.url = url;
        options.data = body;
        return this.request(options).then(function (_a) {
            var data = _a.data;
            return data;
        });
    };
    /**
     * Make a DEL request.
     * ```ts
     * await http.del("/users/1");
     * ```
     *
     * @param url       Complete url
     * @param options   Request options
     */
    HttpClient.prototype.del = function (url, options) {
        if (options === void 0) { options = {}; }
        options.method = "DELETE";
        options.url = url;
        return this.request(options).then(function (_a) {
            var data = _a.data;
            return data;
        });
    };
    tslib_1.__decorate([
        oly_1.state,
        tslib_1.__metadata("design:type", Function)
    ], HttpClient.prototype, "axios", void 0);
    tslib_1.__decorate([
        oly_1.inject,
        tslib_1.__metadata("design:type", oly_1.Logger)
    ], HttpClient.prototype, "logger", void 0);
    tslib_1.__decorate([
        oly_1.inject,
        tslib_1.__metadata("design:type", oly_1.Kernel)
    ], HttpClient.prototype, "kernel", void 0);
    return HttpClient;
}());
exports.HttpClient = HttpClient;
//# sourceMappingURL=HttpClient.js.map